pub trait ConsensusManager { // Required method fn stop(&mut self); }
Consensus manager used to stop the consensus thread
Stop the consensus thread Note that we do not take self by value to consume it because it is not allowed to move out of Box<dyn ConsensusManager> This will improve if the unsized_fn_params feature stabilizes enough to be safely usable.
Box<dyn ConsensusManager>
unsized_fn_params